@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.managedidentities_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -205,9 +216,9 @@ class ManagedIdentitiesServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, ManagedIdentitiesServiceTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the managed identities service client.
@@ -251,15 +262,15 @@ class ManagedIdentitiesServiceAsyncClient:
 
     async def create_microsoft_ad_domain(
         self,
-        request: Union[
-            managed_identities_service.CreateMicrosoftAdDomainRequest, dict
+        request: Optional[
+            Union[managed_identities_service.CreateMicrosoftAdDomainRequest, dict]
         ] = None,
         *,
-        parent: str = None,
-        domain_name: str = None,
-        domain: resource.Domain = None,
+        parent: Optional[str] = None,
+        domain_name: Optional[str] = None,
+        domain: Optional[resource.Domain] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Creates a Microsoft AD domain.
@@ -296,13 +307,13 @@ class ManagedIdentitiesServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.managedidentities_v1.types.CreateMicrosoftAdDomainRequest, dict]):
+            request (Optional[Union[google.cloud.managedidentities_v1.types.CreateMicrosoftAdDomainRequest, dict]]):
                 The request object. Request message for
                 [CreateMicrosoftAdDomain][google.cloud.managedidentities.v1.CreateMicrosoftAdDomain]
             parent (:class:`str`):
@@ -409,13 +420,13 @@ class ManagedIdentitiesServiceAsyncClient:
 
     async def reset_admin_password(
         self,
-        request: Union[
-            managed_identities_service.ResetAdminPasswordRequest, dict
+        request: Optional[
+            Union[managed_identities_service.ResetAdminPasswordRequest, dict]
         ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> managed_identities_service.ResetAdminPasswordResponse:
         r"""Resets a domain's administrator password.
@@ -447,7 +458,7 @@ class ManagedIdentitiesServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.managedidentities_v1.types.ResetAdminPasswordRequest, dict]):
+            request (Optional[Union[google.cloud.managedidentities_v1.types.ResetAdminPasswordRequest, dict]]):
                 The request object. Request message for
                 [ResetAdminPassword][google.cloud.managedidentities.v1.ResetAdminPassword]
             name (:class:`str`):
@@ -513,11 +524,13 @@ class ManagedIdentitiesServiceAsyncClient:
 
     async def list_domains(
         self,
-        request: Union[managed_identities_service.ListDomainsRequest, dict] = None,
+        request: Optional[
+            Union[managed_identities_service.ListDomainsRequest, dict]
+        ] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListDomainsAsyncPager:
         r"""Lists domains in a project.
@@ -550,7 +563,7 @@ class ManagedIdentitiesServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.managedidentities_v1.types.ListDomainsRequest, dict]):
+            request (Optional[Union[google.cloud.managedidentities_v1.types.ListDomainsRequest, dict]]):
                 The request object. Request message for
                 [ListDomains][google.cloud.managedidentities.v1.ListDomains]
             parent (:class:`str`):
@@ -628,11 +641,13 @@ class ManagedIdentitiesServiceAsyncClient:
 
     async def get_domain(
         self,
-        request: Union[managed_identities_service.GetDomainRequest, dict] = None,
+        request: Optional[
+            Union[managed_identities_service.GetDomainRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resource.Domain:
         r"""Gets information about a domain.
@@ -664,7 +679,7 @@ class ManagedIdentitiesServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.managedidentities_v1.types.GetDomainRequest, dict]):
+            request (Optional[Union[google.cloud.managedidentities_v1.types.GetDomainRequest, dict]]):
                 The request object. Request message for
                 [GetDomain][google.cloud.managedidentities.v1.GetDomain]
             name (:class:`str`):
@@ -730,12 +745,14 @@ class ManagedIdentitiesServiceAsyncClient:
 
     async def update_domain(
         self,
-        request: Union[managed_identities_service.UpdateDomainRequest, dict] = None,
+        request: Optional[
+            Union[managed_identities_service.UpdateDomainRequest, dict]
+        ] = None,
         *,
-        domain: resource.Domain = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        domain: Optional[resource.Domain] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Updates the metadata and configuration of a domain.
@@ -770,13 +787,13 @@ class ManagedIdentitiesServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.managedidentities_v1.types.UpdateDomainRequest, dict]):
+            request (Optional[Union[google.cloud.managedidentities_v1.types.UpdateDomainRequest, dict]]):
                 The request object. Request message for
                 [UpdateDomain][google.cloud.managedidentities.v1.UpdateDomain]
             domain (:class:`google.cloud.managedidentities_v1.types.Domain`):
@@ -870,11 +887,13 @@ class ManagedIdentitiesServiceAsyncClient:
 
     async def delete_domain(
         self,
-        request: Union[managed_identities_service.DeleteDomainRequest, dict] = None,
+        request: Optional[
+            Union[managed_identities_service.DeleteDomainRequest, dict]
+        ] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes a domain.
@@ -904,13 +923,13 @@ class ManagedIdentitiesServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.managedidentities_v1.types.DeleteDomainRequest, dict]):
+            request (Optional[Union[google.cloud.managedidentities_v1.types.DeleteDomainRequest, dict]]):
                 The request object. Request message for
                 [DeleteDomain][google.cloud.managedidentities.v1.DeleteDomain]
             name (:class:`str`):
@@ -994,12 +1013,14 @@ class ManagedIdentitiesServiceAsyncClient:
 
     async def attach_trust(
         self,
-        request: Union[managed_identities_service.AttachTrustRequest, dict] = None,
+        request: Optional[
+            Union[managed_identities_service.AttachTrustRequest, dict]
+        ] = None,
         *,
-        name: str = None,
-        trust: resource.Trust = None,
+        name: Optional[str] = None,
+        trust: Optional[resource.Trust] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Adds an AD trust to a domain.
@@ -1037,13 +1058,13 @@ class ManagedIdentitiesServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.managedidentities_v1.types.AttachTrustRequest, dict]):
+            request (Optional[Union[google.cloud.managedidentities_v1.types.AttachTrustRequest, dict]]):
                 The request object. Request message for
                 [AttachTrust][google.cloud.managedidentities.v1.AttachTrust]
             name (:class:`str`):
@@ -1128,13 +1149,15 @@ class ManagedIdentitiesServiceAsyncClient:
 
     async def reconfigure_trust(
         self,
-        request: Union[managed_identities_service.ReconfigureTrustRequest, dict] = None,
+        request: Optional[
+            Union[managed_identities_service.ReconfigureTrustRequest, dict]
+        ] = None,
         *,
-        name: str = None,
-        target_domain_name: str = None,
-        target_dns_ip_addresses: Sequence[str] = None,
+        name: Optional[str] = None,
+        target_domain_name: Optional[str] = None,
+        target_dns_ip_addresses: Optional[MutableSequence[str]] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Updates the DNS conditional forwarder.
@@ -1166,13 +1189,13 @@ class ManagedIdentitiesServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.managedidentities_v1.types.ReconfigureTrustRequest, dict]):
+            request (Optional[Union[google.cloud.managedidentities_v1.types.ReconfigureTrustRequest, dict]]):
                 The request object. Request message for
                 [ReconfigureTrust][google.cloud.managedidentities.v1.ReconfigureTrust]
             name (:class:`str`):
@@ -1191,7 +1214,7 @@ class ManagedIdentitiesServiceAsyncClient:
                 This corresponds to the ``target_domain_name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            target_dns_ip_addresses (:class:`Sequence[str]`):
+            target_dns_ip_addresses (:class:`MutableSequence[str]`):
                 Required. The target DNS server IP
                 addresses to resolve the remote domain
                 involved in the trust.
@@ -1270,12 +1293,14 @@ class ManagedIdentitiesServiceAsyncClient:
 
     async def detach_trust(
         self,
-        request: Union[managed_identities_service.DetachTrustRequest, dict] = None,
+        request: Optional[
+            Union[managed_identities_service.DetachTrustRequest, dict]
+        ] = None,
         *,
-        name: str = None,
-        trust: resource.Trust = None,
+        name: Optional[str] = None,
+        trust: Optional[resource.Trust] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Removes an AD trust.
@@ -1313,13 +1338,13 @@ class ManagedIdentitiesServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.managedidentities_v1.types.DetachTrustRequest, dict]):
+            request (Optional[Union[google.cloud.managedidentities_v1.types.DetachTrustRequest, dict]]):
                 The request object. Request message for
                 [DetachTrust][google.cloud.managedidentities.v1.DetachTrust]
             name (:class:`str`):
@@ -1406,12 +1431,14 @@ class ManagedIdentitiesServiceAsyncClient:
 
     async def validate_trust(
         self,
-        request: Union[managed_identities_service.ValidateTrustRequest, dict] = None,
+        request: Optional[
+            Union[managed_identities_service.ValidateTrustRequest, dict]
+        ] = None,
         *,
-        name: str = None,
-        trust: resource.Trust = None,
+        name: Optional[str] = None,
+        trust: Optional[resource.Trust] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Validates a trust state, that the target domain is
@@ -1451,13 +1478,13 @@ class ManagedIdentitiesServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.managedidentities_v1.types.ValidateTrustRequest, dict]):
+            request (Optional[Union[google.cloud.managedidentities_v1.types.ValidateTrustRequest, dict]]):
                 The request object. Request message for
                 [ValidateTrust][google.cloud.managedidentities.v1.ValidateTrust]
             name (:class:`str`):
@@ -1549,14 +1576,9 @@ class ManagedIdentitiesServiceAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-managed-identities",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("ManagedIdentitiesServiceAsyncClient",)
